changeset 10424:bc97f64c21c2 v8.0.0106

commit https://github.com/vim/vim/commit/0945eaface83e78138fbd40f95cc590bab0e8c86 Author: Bram Moolenaar <Bram@vim.org> Date: Tue Nov 29 22:10:48 2016 +0100 patch 8.0.0106 Problem: Cannot use a semicolon in 'backupext'. (Jeff) Solution: Allow for a few more characters when "secure" isn't set.
author Christian Brabandt <cb@256bit.org>
date Tue, 29 Nov 2016 22:15:03 +0100
parents 45fa8b5f8b5b
children a4e378d55cc1
files src/option.c src/version.c
diffstat 2 files changed, 6 insertions(+), 2 deletions(-) [+]
line wrap: on
line diff
--- a/src/version.c
+++ b/src/version.c
@@ -765,6 +765,8 @@ static char *(features[]) =
 static int included_patches[] =
 {   /* Add new patch number below this line */
 /**/
+    106,
+/**/
     105,
 /**/
     104,
--- a/src/option.c
+++ b/src/option.c
@@ -5879,9 +5879,11 @@ did_set_string_option(
 
     /* Check for a "normal" directory or file name in some options.  Disallow a
      * path separator (slash and/or backslash), wildcards and characters that
      * are often illegal in a file name. */
     else if (((options[opt_idx].flags & P_NFNAME)
-		    && vim_strpbrk(*varp, (char_u *)"/\\*?[|;&<>\r\n") != NULL)
+		    && vim_strpbrk(*varp, (char_u *)(secure
+			    ? "/\\*?[|;&<>\r\n" : "/\\*?[<>\r\n")) != NULL)
 	  || ((options[opt_idx].flags & P_NDNAME)
 		    && vim_strpbrk(*varp, (char_u *)"*?[|;&<>\r\n") != NULL))
     {
@@ -5879,9 +5879,11 @@ did_set_string_option(
     /* Check for a "normal" directory or file name in some options.  Disallow a
      * path separator (slash and/or backslash), wildcards and characters that
-     * are often illegal in a file name. */
+     * are often illegal in a file name. Be more permissive if "secure" is off.
+     */
     else if (((options[opt_idx].flags & P_NFNAME)